@@ -1,4 +1,4 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from typing import Optional, Sequence
 from px_settings.contrib.django import settings as s
 
@@ -10,7 +10,9 @@ __all__ = 'Settings', 'settings',
 @dataclass
 class Settings:
     REGISTRY: str = 'wcd_user_checks.globals.registry'
-    DEFINITIONS: Optional[Sequence[str]] = None
+    DEFINITIONS: Optional[Sequence[str]] = field(default_factory=lambda: [
+        'wcd_user_checks.builtins.MANUAL_CHECK_DEFINITION',
+    ])
     CACHE: str = 'default'
 
 
