@@ -93,3 +93,13 @@ class UserCheck(models.Model):
             return self.state
 
         return get_registry()[self.reason].get_state_display(self.state)
+
+    def clone_object(self):
+        data = {
+            field: getattr(self, field)
+            for field in (
+                'pk', 'user_id', 'reason', 'state', 'message', 'meta',
+                'is_reviewed', 'is_passed', 'created_at', 'updated_at',
+            )
+        }
+        return self.__class__(**data)
